% [] = STK_PLOT_MOO_PROGRESS(DHV_seq, dhv_theo)
% plots the progress of a multi-objective optimization.
%
% CALL: [] = STK_PLOT_MOO_PROGRESS(DHV_SEQ)
% plots the progress of the dominated hypervolume in a multi-objective
% optimisation.
%
% CALL: [] = STK_PLOT_MOO_PROGRESS(DHV_SEQ, DHV_THEO)
% plots the progress of the dominated hypervolume in a multi-objective
% optimisation when the theorical dominated hypervolume is known. Progress
% displayed in percentage
%
% See also stk_example_boo01, stk_example_boo02, stk_example_boo03

% Copyright Notice
%
%    Copyright (C) 2017 CentraleSupelec
%
%    Authors:  Etienne Leloup           <etienne.leloup@free.fr>
%              Guillaume Maistre-Bazin  <g.maistre.bazin@gmail.com>
%              Lucain Pouget            <lucainp@gmail.com>
%              Julien Bect              <julien.bect@centralesupelec.fr>

% Copying Permission Statement
%
%    This file is part of STK-contrib-moo-1
%      (https://sourceforge.net/p/kriging/contrib-moo-1/).
%
%    STK-contrib-moo-1 is free software;  you can redistribute it  and/or
%    modify it  under the terms of the  GNU Lesser General Public License
%    as published by the Free Software Foundation;  either version 2.1 of
%    the License, or (at your option) any later version.
%
%    STK-contrib-moo-1 is distributed in the hope that it will be useful,
%    but  WITHOUT  ANY  WARRANTY;  without even  the implied  warranty of
%    MERCHANTABILITY or FITNESS  FOR A  PARTICULAR PURPOSE.  See the  GNU
%    Lesser General Public License for more details.
%
%    You should  have received  a copy  of the  GNU Lesser General Public
%    License along with STK-contrib-moo-1;  if not, see
%                                          <http://www.gnu.org/licenses/>.

function stk_plot_moo_progress (DHV_seq, dhv_theo)

if nargin < 2
    dhv_theo = 0;
end

if dhv_theo < 0
    stk_error ('Theorical dominated hypervolume cannot be negative', 'InvalidArgument');
end

hold off
if dhv_theo > 0  %True Pareto front is known
    plot (100 * DHV_seq / dhv_theo, 'b-');
    hold on
    plot (100 * ones( length (DHV_seq), 1), 'r-');
    stk_ylabel ('dominated HV (%)');
    stk_title (sprintf ('DHV: %.2f%%', 100 * DHV_seq(end) / dhv_theo));
else
    plot (DHV_seq, 'b-');
    stk_ylabel ('dominated HV');
    stk_title (sprintf ('DHV: %.4e', DHV_seq(end)));
end

end % function
