% STK_SMC_REWEIGHT reweights an SMC sample
%
% CALL: SMC = stk_smc_reweight (SMC, UPDF)
%
%    reweights the SMC sample using the un-normalized pdf UPDF.
%
% See also stk_optim_ehvi_smc, stk_smc_initialize,
%          stk_smc_move, stk_smc_resample

% Copyright Notice
%
%    Copyright (C) 2017 CentraleSupelec
%
%    Authors:  Julien Bect  <julien.bect@centralesupelec.fr>

% Copying Permission Statement
%
%    This file is part of STK-contrib-moo-1
%      (https://sourceforge.net/p/kriging/contrib-moo-1/).
%
%    STK-contrib-moo-1 is free software;  you can redistribute it  and/or
%    modify it  under the terms of the  GNU Lesser General Public License
%    as published by the Free Software Foundation;  either version 2.1 of
%    the License, or (at your option) any later version.
%
%    STK-contrib-moo-1 is distributed in the hope that it will be useful,
%    but  WITHOUT  ANY  WARRANTY;  without even  the implied  warranty of
%    MERCHANTABILITY or FITNESS  FOR A  PARTICULAR PURPOSE.  See the  GNU
%    Lesser General Public License for more details.
%
%    You should  have received  a copy  of the  GNU Lesser General Public
%    License along with STK-contrib-moo-1;  if not, see
%                                          <http://www.gnu.org/licenses/>.

function smc = stk_smc_reweight (smc, updf)

if any (isnan (smc.updf_val)) || any (isnan (smc.weights))
    error ('There are NaNs in smc.updf_val or smc.weights');
end

if ~ all ((smc.updf_val > 0) & (smc.weights > 0))
    error ('Particles should have a non-negative weight at this point');
end

% Compute un-normalized pdf values
updf_val = updf (smc.particles);

% Compute un-normalized weights
weights = smc.weights .* updf_val ./ smc.updf_val;

% Compute sum of weights
S = sum (weights);
if ~ (S > 0)
    error ('Un-normalized weights should have a non-negative sum');
end

% Note: this problem usually occurs when a new evaluation point (or batch of
% evaluations) brings a large improvement, creating a very abrupt change of
% density that SMC fails to follow.  The solution would be to implement more
% progressive transitions as described in Feliot et al (2017).

% Update smc structure
smc.weights  = weights / S;
smc.updf_fun = updf;
smc.updf_val = updf_val;

end % function
